/*
		 Found GPGGA string.  It has 14 commas total.  Its NMEA sentence structure is:

		 $GPGAA,hhmmss.ss,ddmm.mmmm,n,dddmm.mmmm,e,q,ss,y.y,a.a,z,g.g,z,t.t,iii*CC
		 |    |    |    |    |    |    |    |    |    |    |    |    |    |    |
		 0   	   1         2         3         4         5         6         7
		 0123456789012345678901234567890123456789012345678901234567890123456789012

		 where:

		 GPGAA		: GPS fixed data identifier
		 hhmmss.ss	: Coordinated Universal Time (UTC), also known as GMT
		 ddmm.mmmm,n	: Latitude in degrees, minutes and cardinal sign
		 dddmm.mmmm,e	: Longitude in degrees, minutes and cardinal sign
		 q		: Quality of fix.  1 = there is a fix
		 ss		: Number of satellites being used
		 y.y		: Horizontal dilution of precision
		 a.a,M		: GPS antenna altitude in meters
		 g.g,M		: geoidal separation in meters
		 t.t		: Age of the defferential correction data
		 iiii		: Deferential station's ID
		 *CC		: checksum for the sentence
	      */

#ifndef _gps_H
#define _gps_H
#pragma once

#define gps_init_delay 0
#define Baud_Rate_Gps CBR_4800
#define max_size 600
#define bytesRead 500
#define TRUE 1
#define FALSE 0
#define NO_LINK -1

/*struct xyz
{
	double x;
	double y;
	double z;
};*/

class GPS
{
public:
  GPS()
	{
		utcTime=0;
		sgtTime=0;		// Coordinated Universal Time and Eastern Standard Time
		utcHour=0;
		sgtHour=0;
		utcMinutes=0;
		sgtMinutes=0;
		utcSeconds=0;
		sgtSeconds=0;

		latitude=0.0;
		latDegrees=0;
		latMinutes=0;
		//latitudeCardinalString[3]="";

		longitude=0.0;
		longDegrees=0;
		longMinutes=0.0;
		//longitudeCardinalString[3]="";

		positionFix=0;
		satelliteNo=0;

		arcDeg=0.0;
		//courseRef[2]="";
		groundSpeed=0.0;
		//unitOfSpeed[2]="";
		altitude=0.0;
		//unitOfAltitude[2]="";
	}
  long utcTime, sgtTime;		// Coordinated Universal Time and Eastern Standard Time 
  long utcHour, sgtHour;
  long utcMinutes, sgtMinutes;
  long utcSeconds, sgtSeconds;

  float latitude;
  int latDegrees;
  float latMinutes;
  char  latitudeCardinalString[3];

  float longitude;
  int longDegrees;
  float longMinutes;
  char  longitudeCardinalString[3];

  int positionFix;
  int satelliteNo;

  float  arcDeg;
  char courseRef[2];
  float groundSpeed;
  char unitOfSpeed[2];
  float altitude;
  char unitOfAltitude[2];
};



//HANDLE gps_handle;

int gps_chksum(char *nmea_line,char rw);
void gps_open_serial(int port);
void gps_read();
void gps_write();
int gps_info(char *gps_buff_sample);

#endif