/*

Crossbow IMU Data Packet Format

Byte	DMU-VG
  0		Header (255)
  1		Roll (MSB)
  2		Roll (LSB)
  3		Pitch (MSB)
  4		Pitch (LSB)
  5		Roll Rate X (MSB)
  6		Roll Rate X (LSB)
  7		Pitch Rate (MSB)
  8		Pitch Rate Y (LSB)
  9		Yaw Rate Z (MSB)
  10	Yaw Rate (LSB)
  11	Acceleration X (MSB)
  12	Acceleration X (LSB)
  13	Acceleration Y (MSB)
  14	Acceleration Y (LSB)
  15	Acceleration Z (MSB)
  16	Acceleration Z (LSB)
  17	Temp Sensor Voltage (MSB)
  18	Temp Sensor Voltage (LSB)
  19	Time (MSB)
  20	Time (LSB)
  21	Checksum
  
  */
#ifndef _ins_H
#define _ins_H
#pragma once

#define Baud_Rate_Ins CBR_38400
#define data_packet_size 24
#define zero_bias_delay 0    //50//0-255 sec
#define time_constant 0	  //50//0-255 sec
#define TRUE 1
#define FALSE 0
#define GR 2.0
#define AR 100.0
#define SCALE_R_P 180
#define SCALE_Y 80

class INS
{
public:
	INS()
	{
		roll_rate=0;
		pitch_rate=0;
		yaw_rate=0;

		roll_angle=0;
		pitch_angle=0;
		yaw_angle=0;

		acclx=0;
		accly=0;
		acclz=0;

		time=0;
		temp_voltage=0;
		chkbit=0;
		part_no=0;
	}
	double roll_rate;
	double pitch_rate;
	double yaw_rate;

	double roll_angle;
	double pitch_angle;
	double yaw_angle;

	double acclx;
	double accly;
	double acclz;

	double time;
	double temp_voltage;
	double chkbit;
	double part_no;
};


void ins_open_serial(int port);
void ins_read(char mode);
char ins_config();
double ins_chksum(byte ins_data[data_packet_size],int k);
void ins_info(byte ins_data[data_packet_size],int k);
double accl_calc(double accl);
double rot_calc(double rot);
double angle_calc(double angle,char type);

#endif
